[Piglit] [PATCH] framework/test/shader_test: use -fbo option for shader tests

Brian Paul brianp at vmware.com
Wed Apr 26 17:01:42 UTC 2017


Running shader tests with a FBO instead of a window is faster in some
environments.  For example, for a Windows7 VM (debug build of everything)
the runtime of a large piglit run drops from to 3.7 hours to 3.2 hours.
In a Linux guest, piglit-run.py -t built-in-functions drops from 19
minutes to 15 minutes.

No regressions found with VMware driver in Windows VM and Linux VM.
---
 framework/test/shader_test.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/framework/test/shader_test.py b/framework/test/shader_test.py
index 8c493d5..d98ec98 100644
--- a/framework/test/shader_test.py
+++ b/framework/test/shader_test.py
@@ -169,8 +169,8 @@ class ShaderTest(FastSkipMixin, PiglitBaseTest):
 
     @PiglitBaseTest.command.getter
     def command(self):
-        """ Add -auto to the test command """
-        return self._command + ['-auto']
+        """ Add -auto and -fbo to the test command """
+        return self._command + ['-auto', '-fbo']
 
 
 class MultiShaderTest(ReducedProcessMixin, PiglitBaseTest):
-- 
1.9.1



More information about the Piglit mailing list